@@ -802,8 +802,8 @@ def database_add(ctx: Context, database: Callable[..., Database], table: str, fi
     The JSON file must contain fields for all columns of the table. For a list of columns for each table, please see
     the help of the {yellow}{db_app}{reset} command.
 
-    By default, the program will throw an error when trying to add an entry that already exists. To override this
-    behaviour and ignore existing entries, use the {yellow}--replace{reset} option.
+    The program will throw an error when trying to add an entry that already exists. To edit entries use the
+    {yellow}{db_app} edit{reset} command, or remove the entry with {yellow}{db_app} remove{reset}.
     """
     db: Database = database()
     db_table: Table = get_table(db, table)
@@ -816,12 +816,11 @@ def database_add(ctx: Context, database: Callable[..., Database], table: str, fi
         raise BadParameter(f"Missing fields {set(map(str.upper, db_table.columns)) - set(data.keys())}"
                            f" for table {table}",
                            ctx, get_param(ctx, "file"))
-    elif not replace and (id_ := data[idc := db_table.key.name.upper()]) in db_table:
-        raise BadParameter(f"Entry with {idc} {id_!r} already exists in {table} table, but '--replace' is not set.",
-                           ctx, get_param(ctx, "file"))
+    elif (id_ := data[idc := db_table.key.name.upper()]) in db_table:
+        raise BadParameter(f"Entry with {idc} {id_!r} already exists in {table} table.", ctx, get_param(ctx, "file"))
 
     add_history(db, ctx, table=table, file=file.name, submission_file=submission_file is not None,
-                submission_thumbnail=submission_thumbnail is not None, replace=replace)
+                submission_thumbnail=submission_thumbnail is not None)
 
     if table.lower() == submissions_table.lower():
         sub_files_orig, sub_thumb_orig = db.submissions.get_submission_files(data["ID"])
@@ -835,12 +834,12 @@ def database_add(ctx: Context, database: Callable[..., Database], table: str, fi
         sub_thumb: bytes | None = submission_thumbnail.read_bytes() if submission_thumbnail else None
 
         try:
-            db.submissions.save_submission(data, sub_files, sub_thumb, replace=replace)
+            db.submissions.save_submission(data, sub_files, sub_thumb)
         finally:
             db.commit()
     else:
         try:
-            db_table.insert(db_table.format_entry(data), replace=replace)
+            db_table.insert(db_table.format_entry(data))
         finally:
             db.commit()
 
@@ -902,23 +901,24 @@ def database_edit(ctx: Context, database: Callable[..., Database], table: str, _
     if (entry := db_table[_id]) is None:
         raise BadParameter(f"No entry with ID {_id} in {table}.", ctx, get_param(ctx, "_id"))
 
-    filesaved: int = data.get(f := SubmissionsColumns.FILESAVED.value.name, entry[f])
+    if db_table.name == db.submissions.name:
+        filesaved: int = data.get(f := SubmissionsColumns.FILESAVED.value.name, entry[f])
 
-    if submission_file:
-        if not add_submission_files and entry[SubmissionsColumns.FILEEXT.value.name]:
-            fs, _ = db.submissions.get_submission_files(_id)
-            for f in fs:
-                f.unlink()
-        exts: list[str] = entry[SubmissionsColumns.FILEEXT.value.name] if add_submission_files else []
-        for n, f in enumerate(submission_file,
-                              len(entry[SubmissionsColumns.FILEEXT.value.name]) if add_submission_files else 0):
-            exts.append(db.submissions.save_submission_file(_id, f.read_bytes(), "submission", "", n))
-        filesaved = (filesaved & 0b001) + 0b110
-        data |= {SubmissionsColumns.FILESAVED.value.name: filesaved, SubmissionsColumns.FILEEXT.value.name: exts}
-    if submission_thumbnail:
-        db.submissions.save_submission_thumbnail(_id, submission_thumbnail.read_bytes())
-        filesaved = (filesaved & 0b100) + (filesaved & 0b010) + 0b001
-        data |= {SubmissionsColumns.FILESAVED.value.name: filesaved}
+        if submission_file:
+            if not add_submission_files and entry[SubmissionsColumns.FILEEXT.value.name]:
+                fs, _ = db.submissions.get_submission_files(_id)
+                for f in fs:
+                    f.unlink()
+            exts: list[str] = entry[SubmissionsColumns.FILEEXT.value.name] if add_submission_files else []
+            for n, f in enumerate(submission_file, len(exts)):
+                exts.append(db.submissions.save_submission_file(_id, f.read_bytes(), "submission",
+                                                                f.suffix.removeprefix("."), n))
+            filesaved = (filesaved & 0b001) + 0b110
+            data |= {SubmissionsColumns.FILESAVED.value.name: filesaved, SubmissionsColumns.FILEEXT.value.name: exts}
+        if submission_thumbnail:
+            db.submissions.save_submission_thumbnail(_id, submission_thumbnail.read_bytes())
+            filesaved = (filesaved & 0b100) + (filesaved & 0b010) + 0b001
+            data |= {SubmissionsColumns.FILESAVED.value.name: filesaved}
 
     if data:
         db_table.update(Sb(db_table.key.name).__eq__(_id), db_table.format_entry(data))
